@@ -1,4 +1,4 @@
-__version__ = '0.0.21'
+__version__ = '0.0.23'
 
 import evaics.sdk as sdk
 from types import SimpleNamespace
@@ -10,7 +10,7 @@ import uuid
 import zlib
 import hashlib
 import pyaltt2.crypto
-import elbus
+import busrt
 try:
     import rapidjson as json
 except:
@@ -37,7 +37,7 @@ def get_key_val(key_id):
     except KeyError:
         key = unpack(
             _d.service.rpc.call(
-                _d.key_svc, elbus.rpc.Request('key.get', pack(
+                _d.key_svc, busrt.rpc.Request('key.get', pack(
                     {'i': key_id}))).wait_completed().get_payload())['key']
         key_cache[key_id] = key
         return key
@@ -49,7 +49,7 @@ def mark_node(node, status, info=None):
         payload['info'] = info
     _d.service.bus.send(
         f'RPL/NODE/{node}',
-        elbus.client.Frame(pack(payload), tp=elbus.client.OP_PUBLISH))
+        busrt.client.Frame(pack(payload), tp=busrt.client.OP_PUBLISH))
 
 
 def jreq(id, method, params=None):
@@ -141,8 +141,9 @@ class LegacyNode:
         data = rid + zlib.compress(pack(payload))
         cb = Callback()
         send_api_request(
-            request_id, controller_id, header + self.key_lid.encode() + b'\x00' +
-            encrypt(data, private_key, key_is_hash=True), cb.data_handler)
+            request_id, controller_id, header + self.key_lid.encode() +
+            b'\x00' + encrypt(data, private_key, key_is_hash=True),
+            cb.data_handler)
         if not cb.completed.wait(self.timeout):
             finish_api_request(request_id)
             raise TimeoutError
@@ -292,7 +293,7 @@ class LegacyNode:
                     inventory.append(v4lmacro)
             _d.service.bus.send(
                 f'RPL/INVENTORY/{self.id}',
-                elbus.client.Frame(pack(inventory), tp=elbus.client.OP_PUBLISH))
+                busrt.client.Frame(pack(inventory), tp=busrt.client.OP_PUBLISH))
             self.online = True
             mark_node(self.id,
                       'online',
@@ -330,7 +331,7 @@ def process_message(client, userdata, message):
                     'nstatus'] and state['value'] == state['nvalue'] else 1
             _d.service.bus.send(
                 f'RPL/ST/{state["oid"].replace(":", "/",1)}',
-                elbus.client.Frame(pack(v4state), tp=elbus.client.OP_PUBLISH))
+                busrt.client.Frame(pack(v4state), tp=busrt.client.OP_PUBLISH))
     elif topic == 'controller/discovery':
         node_id = message.payload.decode().split('/')[1]
         try:
@@ -366,7 +367,7 @@ def handle_rpc(event):
     method = event.method.decode()
     if method == 'node.list':
         if event.get_payload():
-            raise elbus.rpc.RpcException(code=sdk.ERR_CODE_INVALID_PARAMS)
+            raise busrt.rpc.RpcException(code=sdk.ERR_CODE_INVALID_PARAMS)
         return pack(
             sorted([c.serialize() for _, c in _d.lc.items()],
                    key=lambda k: k['id']))
@@ -375,12 +376,12 @@ def handle_rpc(event):
             params = unpack(event.get_payload())
             node_id = params['i']
         except Exception as e:
-            raise elbus.rpc.RpcException(str(e), sdk.ERR_CODE_INVALID_PARAMS)
+            raise busrt.rpc.RpcException(str(e), sdk.ERR_CODE_INVALID_PARAMS)
         try:
             node = _d.lc[node_id]
             node.force_reload()
         except KeyError:
-            raise elbus.rpc.RpcException(f'node {node_id} not found',
+            raise busrt.rpc.RpcException(f'node {node_id} not found',
                                          sdk.ERR_CODE_NOT_FOUND)
     # end of user method, the next methods are proxied to v3 nodes
     elif method.startswith('lvar.'):
@@ -401,7 +402,7 @@ def handle_rpc(event):
             elif rm == 'decr':
                 rm = 'decrement'
         except Exception as e:
-            raise elbus.rpc.RpcException(str(e), sdk.ERR_CODE_INVALID_PARAMS)
+            raise busrt.rpc.RpcException(str(e), sdk.ERR_CODE_INVALID_PARAMS)
         node = _d.lc[node_id]
         node.call('lm', rm, p)
         return pack(None)
@@ -421,7 +422,7 @@ def handle_rpc(event):
             if 'wait' in params:
                 p['w'] = params['wait']
         except Exception as e:
-            raise elbus.rpc.RpcException(str(e), sdk.ERR_CODE_INVALID_PARAMS)
+            raise busrt.rpc.RpcException(str(e), sdk.ERR_CODE_INVALID_PARAMS)
         node = _d.lc[node_id]
         act_info = node.call('uc', 'action', p)
         return pack(to_v4action(act_info, node_id))
@@ -433,7 +434,7 @@ def handle_rpc(event):
             u = uuid.UUID(bytes=params['u'])
             ctp = 'lm' if i.startswith('lmacro:') else 'uc'
         except Exception as e:
-            raise elbus.rpc.RpcException(str(e), sdk.ERR_CODE_INVALID_PARAMS)
+            raise busrt.rpc.RpcException(str(e), sdk.ERR_CODE_INVALID_PARAMS)
         node = _d.lc[node_id]
         act_info = node.call(ctp, 'result', {'u': str(u)})
         return pack(to_v4action(act_info, node_id))
@@ -452,7 +453,7 @@ def handle_rpc(event):
             if 'wait' in params:
                 p['w'] = params['wait']
         except Exception as e:
-            raise elbus.rpc.RpcException(str(e), sdk.ERR_CODE_INVALID_PARAMS)
+            raise busrt.rpc.RpcException(str(e), sdk.ERR_CODE_INVALID_PARAMS)
         node = _d.lc[node_id]
         act_info = node.call('lm', 'run', p)
         return pack(to_v4action(act_info, node_id))
@@ -540,7 +541,8 @@ def run():
         reload_interval = c['reload_interval']
         timeout = c.get('timeout', service.timeout['default'])
         controllers = c.get('controllers', [])
-        c = LegacyNode(id, key_id, key_lid, reload_interval, timeout, controllers)
+        c = LegacyNode(id, key_id, key_lid, reload_interval, timeout,
+                       controllers)
         _d.lc[id] = c
         mark_node(c.id, 'offline')
     pubsub = psrt.Client(**pubsub_cfg)
